@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
 import com.openexchange.groupware.infostore.InfostoreFacade;
+import com.openexchange.html.HTMLService;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.publish.PublicationDataLoaderService;
 import com.openexchange.publish.microformats.ContactPictureServlet;
@@ -66,7 +67,7 @@ import com.openexchange.publish.microformats.InfostoreFileServlet;
 import com.openexchange.publish.microformats.MicroformatServlet;
 import com.openexchange.publish.microformats.OnlinePublicationServlet;
 import com.openexchange.server.osgiservice.DeferredActivator;
-import com.openexchange.templating.TemplateService;
+import com.openexchange.templating.base.TemplateService;
 import com.openexchange.user.UserService;
 import com.openexchange.userconf.UserConfigurationService;
 
@@ -77,7 +78,7 @@ import com.openexchange.userconf.UserConfigurationService;
  */
 public class ServletActivator extends DeferredActivator {
 
-    private static final Log LOG = LogFactory.getLog(ServletActivator.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletActivator.class));
 
     private ServiceTracker tracker;
     
@@ -89,7 +90,7 @@ public class ServletActivator extends DeferredActivator {
 
     private static final Class<?>[] NEEDED_SERVICES = {
         HttpService.class, PublicationDataLoaderService.class, ContextService.class, TemplateService.class,
-        ContactInterfaceDiscoveryService.class, UserConfigurationService.class, UserService.class, InfostoreFacade.class, ConfigurationService.class};
+        ContactInterfaceDiscoveryService.class, UserConfigurationService.class, UserService.class, InfostoreFacade.class, ConfigurationService.class, HTMLService.class};
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -135,19 +136,22 @@ public class ServletActivator extends DeferredActivator {
         final UserConfigurationService userConfigs = getService(UserConfigurationService.class);
         final UserService users = getService(UserService.class);
         final ConfigurationService configService = getService(ConfigurationService.class);
+        final HTMLService htmlService = getService(HTMLService.class);
 
-        if (null == httpService || null == dataLoader || null == contexts || null == templates || null == contacts || null == userConfigs || null == users || configService == null) {
+        if (null == httpService || null == dataLoader || null == contexts || null == templates || null == contacts || null == userConfigs || null == users || configService == null || htmlService == null) {
             return;
         }
 
         activator.setTemplateService(templates);
         
         OnlinePublicationServlet.setContextService(contexts);
-
+        OnlinePublicationServlet.setUserConfigurationService(userConfigs);
+        
         MicroformatServlet.setPublicationDataLoaderService(dataLoader);
         MicroformatServlet.setUserService(users);
         MicroformatServlet.setStringTranslator(customizer);
         MicroformatServlet.setConfigService(configService);
+        MicroformatServlet.setHtmlService(htmlService);
         final MicroformatServlet microformatServlet = new MicroformatServlet();
         
         ContactPictureServlet.setContactInterfaceDiscoveryService(contacts);
