@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,10 @@
 
 package com.openexchange.publish.microformats.tools;
 
+import javax.servlet.http.HttpServletRequest;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.publish.Publication;
+import com.openexchange.tools.servlet.http.Tools;
 
 
 /**
@@ -68,5 +70,9 @@ public class InfostoreTemplateUtils {
             return "/publications/files/"+publication.getContext().getContextId()+"/"+publication.getConfiguration().get("siteName")+"/"+document.getId()+"/current";
         }
     }
+    
+    public String getScheme(HttpServletRequest req) {
+        return Tools.getProtocol(req);
+    }
 
 }
